@@ -411,7 +411,7 @@ impl Certification {
             exportable: true,
             depth: Depth::new(0),
             amount: 120,
-            re_set: RegexSet::everything().ok(),
+            re_set: Some(RegexSet::everything()),
             re_bytes: Vec::new(),
             digest_prefix: None,
         }
@@ -638,17 +638,16 @@ impl Certification {
                 (d, a, RegexSet::from_signature(certification)
                  .expect("internal error"))
             } else {
-                (0, 120, RegexSet::everything()
-                 .expect("internal error"))
+                (0, 120, RegexSet::everything())
             };
 
             t!("<{}, {}> {} <{}, {}> \
                 (depth: {}, amount: {}, scope: {:?})",
-               possible_issuer.keyid(),
+               possible_issuer.cert().keyid(),
                possible_issuer
                .primary_userid()
                .map(|ua| {
-                   String::from_utf8_lossy(ua.value()).into_owned()
+                   String::from_utf8_lossy(ua.userid().value()).into_owned()
                })
                .unwrap_or("[no User ID]".into()),
                if depth > 0 {
