@@ -40,7 +40,6 @@ pub use path::PathError;
 pub use path::CertLints;
 pub use path::CertificationLints;
 pub use path::PathLints;
-mod gossip;
 mod builder;
 pub use builder::NetworkBuilder;
 
@@ -342,19 +341,14 @@ impl<S> Network<S>
         self.maximum_depth
     }
 
-    /// Authenticates the specified binding.
-    ///
-    /// Enough independent paths are gotten to satisfy
-    /// `target_trust_amount`.  A fully trusted authentication is 120.
-    /// If you require that a binding be double authenticated, you can
-    /// specify 240.
-    pub fn authenticate<U, F>(&self, target_userid: U, target_fpr: F,
-                              target_trust_amount: usize)
+    fn authenticate_internal<U, F>(&self, target_userid: U, target_fpr: F,
+                                   target_trust_amount: usize,
+                                   gossip: bool)
         -> Paths
     where U: Borrow<UserID>,
           F: Borrow<Fingerprint>,
     {
-        tracer!(TRACE, "Network::authenticate");
+        tracer!(TRACE, "Network::authenticate_internal");
 
         let target_userid = target_userid.borrow();
         let target_fpr = target_fpr.borrow();
@@ -395,14 +389,18 @@ impl<S> Network<S>
         }
 
         let mut progress = true;
-        'next_path: while progress && paths.amount() < target_trust_amount {
+        'next_path: while progress
+            && (paths.amount() < target_trust_amount || gossip)
+        {
             progress = false;
 
+            let mut gossip_paths = Vec::new();
+
             for self_signed in [true, false] {
                 let auth_paths: BTreeMap<Fingerprint, (Path, usize)>
                     = self.backward_propagate(
                         target_fpr.clone(), target_userid.clone(),
-                        self_signed, &filter);
+                        self_signed, &filter, gossip);
 
                 // Note: the paths returned by backward_propagate may
                 // overlap.  As such, we can only take one.  (Or we need
@@ -450,12 +448,73 @@ impl<S> Network<S>
                     // Prefer paths where the target User ID is self
                     // signed as long as possible.
                     continue 'next_path;
+                } else if gossip {
+                    gossip_paths.extend(auth_paths.into_values());
+                }
+            }
+
+            // No authenticated paths left.
+            assert!(! progress);
+
+            if gossip {
+                // We're looking for gossip paths.  Add the remaining
+                // paths.  But, don't add paths that are just suffixes
+                // of other paths.  To make this easier, we add the
+                // longest paths first so that shorter suffixes are
+                // filtered out when we try to add them.
+                t!("Adding the remaining paths ({}) as gossip paths",
+                   gossip_paths.len());
+
+                gossip_paths.sort_by_key(|(path, _amount)| {
+                    -(path.len() as isize)
+                });
+                for (path, _amount) in gossip_paths.into_iter() {
+                    if ! paths.has_suffix(&path) {
+                        t!("Adding: {:?} (length: {})", path, path.len());
+                        paths.push(path, 0);
+                    } else {
+                        t!("Skipping suffix: {:?}", path);
+                    }
                 }
             }
         }
 
         paths
     }
+
+    /// Authenticates the specified binding.
+    ///
+    /// Enough independent paths are gotten to satisfy
+    /// `target_trust_amount`.  A fully trusted authentication is 120.
+    /// If you require that a binding be double authenticated, you can
+    /// specify 240.
+    pub fn authenticate<U, F>(&self, target_userid: U, target_fpr: F,
+                              target_trust_amount: usize)
+        -> Paths
+    where U: Borrow<UserID>,
+          F: Borrow<Fingerprint>,
+    {
+        self.authenticate_internal(target_userid, target_fpr,
+                                   target_trust_amount, false)
+    }
+
+    /// Gets gossip about the specified binding.
+    ///
+    /// This is like [`Network::authenticate`], but it also includes
+    /// all unauthenticated paths to the target binding.  The
+    /// aggregate trust amount is accurate.
+    ///
+    /// Note: the paths are dedup based on whether they are a suffix
+    /// of another path.  That is, if `A -> B -> C` is a valid gossip
+    /// path, then so is `B -> C`.
+    pub fn gossip<U, F>(&self, target_fpr: F, target_userid: U)
+        -> Paths
+    where U: Borrow<UserID>,
+          F: Borrow<Fingerprint>,
+    {
+        self.authenticate_internal(target_userid, target_fpr,
+                                   0, true)
+    }
 }
 
 #[cfg(test)]
