@@ -90,9 +90,9 @@ use crate as wot;
 /// const P: &StandardPolicy = &StandardPolicy::new();
 ///
 /// # fn main() -> Result<()> {
-/// let (alice, _) = CertBuilder::general_purpose(None, Some("<alice@example.org>)"))
+/// let (alice, _) = CertBuilder::general_purpose(Some("<alice@example.org>)"))
 ///     .generate()?;
-/// let (bob, _) = CertBuilder::general_purpose(None, Some("<bob@example.org>"))
+/// let (bob, _) = CertBuilder::general_purpose(Some("<bob@example.org>"))
 ///     .generate()?;
 ///
 /// let mut cert_store = cert_store::CertStore::empty();
@@ -732,7 +732,7 @@ impl<'a: 'ra, 'ra, S> Store for CertStore<'a, 'ra, S>
                         // But if they already match, then they will
                         // normalize to the same thing, and we can
                         // avoid the cost of doing the normalization.
-                        if let Ok(Some(e)) = userid.email2() {
+                        if let Ok(Some(e)) = userid.email() {
                             if e == email {
                                 Some((cert.fingerprint(), userid.clone()))
                             } else {
@@ -810,10 +810,10 @@ mod test {
         }
 
         let (alice, _) = CertBuilder::general_purpose(
-            None, Some("<alice@example.org>"))
+            Some("<alice@example.org>"))
             .generate()?;
         let (bob, _) = CertBuilder::general_purpose(
-            None, Some("<bob@example.org>"))
+            Some("<bob@example.org>"))
             .generate()?;
 
         let cert_store = cert_store::CertStore::empty();
@@ -878,7 +878,7 @@ mod test {
         // The certificate has a primary key that is also bound as a
         // subkey.
         assert!(ref_cert.keys().subkeys().any(|k| {
-            k.fingerprint() == ref_fpr
+            k.key().fingerprint() == ref_fpr
         }));
 
         let store = CertStore::from_cert_refs(
