@@ -8,7 +8,7 @@ t2=20200301
 t3=20200401
 
 key -t $t0 alice
-key -t $t0 bob -e 45d
+key -t $t0 bob
 key -t $t0 carol
 
 set -x
@@ -19,4 +19,6 @@ certify -t $t1 bob -a 60 -d 1 carol
 certify -t $t3 alice -a 120 -d 1 bob
 certify -t $t3 bob -a 120 -d 1 carol
 
+expire bob 45d
+
 finish
