@@ -160,17 +160,19 @@ function key {
             exit 1
         fi
     else
-        sq --force key generate --cannot-sign --cannot-encrypt --cannot-authenticate \
-           ${expires_in:+--expiry "$expires_in"} \
-           ${time:+--creation-time "$time"} \
+        sq --overwrite key generate --without-password \
+           --cannot-sign --cannot-encrypt --cannot-authenticate \
+           ${expires_in:+--expiration "$expires_in"} \
+           ${time:+--time "$time"} \
            ${userids[@]} \
            --output "$keyfile" \
-           --rev-cert /dev/null
+           --rev-cert - \
+           --own-key >/dev/null
     fi
 
     keyfiles="$keyfiles $keyfile"
 
-    sq key extract-cert "$keyfile" > "$dir"/"$basename".pgp
+    sq --overwrite key delete --cert-file "$keyfile" --output "$dir"/"$basename".pgp
 }
 
 # Certifies a key.
@@ -211,6 +213,7 @@ function certify {
     }
     eval set -- "$options"
 
+    unconstrained=--unconstrained
     while true; do
         case "$1" in
             -a)
@@ -223,11 +226,13 @@ function certify {
                 ;;
             -r)
                 shift
-                regex+=(-r "$1")
+                regex+=(--regex "$1")
+                unconstrained=
                 ;;
             --domain)
                 shift
-                regex+=(-r '<[^>]+[@.]'"$(echo -n "$1" | sed 's/[.]/\\./')"'>$')
+                regex+=(--regex '<[^>]+[@.]'"$(echo -n "$1" | sed 's/[.]/\\./')"'>$')
+                unconstrained=
                 ;;
             -t)
                 shift
@@ -274,13 +279,13 @@ function certify {
         userid="<$target@example.org>"
     fi
 
-    sq certify --amount $amount --depth $depth ${regex[@]} \
+    sq pki vouch authorize --amount $amount --depth $depth ${regex[@]} \
+       $unconstrained \
        ${time:+--time "$time"} \
-       ${expires_in:+--expiry "$expires_in"} \
-       --allow-not-alive-certifier --allow-revoked-certifier \
-       "$dir"/"$signer"-priv.pgp \
-       "$dir"/"$target".pgp \
-       "$userid" > "$dir"/"$target".pgp~
+       ${expires_in:+--expiration "$expires_in"} \
+       --certifier-file "$dir"/"$signer"-priv.pgp \
+       --cert-file "$dir"/"$target".pgp \
+       --userid "$userid" > "$dir"/"$target".pgp~
 
     mv "$dir"/"$target".pgp~ "$dir"/"$target".pgp
 }
@@ -298,7 +303,7 @@ function revoke {
         exit 1
     }
 
-    subcommand=certificate
+    subcommand=
     userid=
     time=
     revoker=
@@ -356,13 +361,61 @@ function revoke {
 
     set -o pipefail
     {
-        sq dearmor "$dir"/"$cert".pgp
-        sq revoke ${subcommand} ${userid:+"$userid"} -B \
+        sq packet dearmor "$dir"/"$cert".pgp
+        sq key ${subcommand} revoke ${userid:+--userid "$userid"} \
            ${time:+--time "$time"} \
-           --revocation-key "$dir"/"$revoker"-priv.pgp \
-           --certificate "$dir"/"$cert".pgp \
-           "$reason" "some message"
-    } | sq toolbox keyring merge > "$dir"/"$cert".pgp~
+           --revoker-file "$dir"/"$revoker"-priv.pgp \
+           --cert-file "$dir"/"$cert".pgp \
+           --reason "$reason" --message "some message" \
+           --output - | sq packet dearmor
+    } | sq keyring merge > "$dir"/"$cert".pgp~
+    set +o pipefail
+
+    mv "$dir"/"$cert".pgp~ "$dir"/"$cert".pgp
+}
+
+# Expires a certificate.
+#
+#   expire CERT TIME
+#
+# CERT is a basename.  The output is written to DIR/CERT.pgp.
+#
+# Time is the expiration time and may be relative.
+function expire {
+    check_init
+
+    function usage {
+        echo "Usage: $0 CERT TIME" 1>&2
+        exit 1
+    }
+
+    time=
+
+    if test $# -lt 2
+    then
+        echo "Too few arguments"
+        usage
+    fi
+
+    if test $# -gt 2
+    then
+        echo "Too many arguments"
+        usage
+    fi
+
+    cert=$1
+    time=$2
+
+    set -x
+
+    set -o pipefail
+    {
+        sq packet dearmor "$dir"/"$cert".pgp
+        sq key expire \
+           --expiration "$time" \
+           --cert-file "$dir"/"$cert"-priv.pgp \
+           --output - | sq packet dearmor
+    } | sq keyring merge > "$dir"/"$cert".pgp~
     set +o pipefail
 
     mv "$dir"/"$cert".pgp~ "$dir"/"$cert".pgp
@@ -372,7 +425,7 @@ function finish {
     find "$dir" -type f -name '*-priv.pgp' | while read f
     do
         cat "${f%-priv.pgp}.pgp"
-    done | sq toolbox keyring merge > "$dir.pgp"
+    done | sq keyring merge > "$dir.pgp"
 
     ./torust.sh "$dir"
 
